# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: casing_inner_class.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "TestInnerClass",
)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    inner: "TestInnerClass" = betterproto.message_field(2)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class TestInnerClass(betterproto.Message):
    """ """

    old_exp: int = betterproto.sint32_field(1)
    """
    
    """
