# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: casing_message_field_uppercase.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    uppercase: int = betterproto_fw.int32_field(1)
    """
    
    """

    uppercase_v2: int = betterproto_fw.int32_field(2)
    """
    
    """

    upper_camel_case: int = betterproto_fw.int32_field(3)
    """
    
    """
