# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: oneof_enum.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'oneof_enum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10oneof_enum.proto\x12\noneof_enum\"X\n\x04Test\x12$\n\x06signal\x18\x01 \x01(\x0e\x32\x12.oneof_enum.SignalH\x00\x12 \n\x04move\x18\x02 \x01(\x0b\x32\x10.oneof_enum.MoveH\x00\x42\x08\n\x06\x61\x63tion\"\x1c\n\x04Move\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05*\x1e\n\x06Signal\x12\x08\n\x04PASS\x10\x00\x12\n\n\x06RESIGN\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'oneof_enum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SIGNAL']._serialized_start=152
  _globals['_SIGNAL']._serialized_end=182
  _globals['_TEST']._serialized_start=32
  _globals['_TEST']._serialized_end=120
  _globals['_MOVE']._serialized_start=122
  _globals['_MOVE']._serialized_end=150
# @@protoc_insertion_point(module_scope)
