# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: map.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from typing import (
    Dict,
)

from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """ """

    counts: Dict[str, int] = betterproto_fw.map_field(
        1, betterproto_fw.TYPE_STRING, betterproto_fw.TYPE_INT32
    )
    """
    
    """
