# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: repeatedpacked.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from typing import (
    List,
)

from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    counts: List[int] = betterproto.int32_field(1)
    """
    
    """

    signed: List[int] = betterproto.sint64_field(2)
    """
    
    """

    fixed: List[float] = betterproto.double_field(3)
    """
    
    """
