# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: import_child_package_from_root.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """
    Tests generated imports when a message in root refers to a message in a child package.
    """

    child: "childpackage.Message" = betterproto.message_field(1)
    """
    
    """


from . import childpackage
