# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: example_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'example_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x65xample_service.proto\x12\x0f\x65xample_service\"A\n\x0e\x45xampleRequest\x12\x16\n\x0e\x65xample_string\x18\x01 \x01(\t\x12\x17\n\x0f\x65xample_integer\x18\x02 \x01(\x03\"B\n\x0f\x45xampleResponse\x12\x16\n\x0e\x65xample_string\x18\x01 \x01(\t\x12\x17\n\x0f\x65xample_integer\x18\x02 \x01(\x03\x32\xf2\x02\n\x04Test\x12V\n\x11\x45xampleUnaryUnary\x12\x1f.example_service.ExampleRequest\x1a .example_service.ExampleResponse\x12Y\n\x12\x45xampleUnaryStream\x12\x1f.example_service.ExampleRequest\x1a .example_service.ExampleResponse0\x01\x12Y\n\x12\x45xampleStreamUnary\x12\x1f.example_service.ExampleRequest\x1a .example_service.ExampleResponse(\x01\x12\\\n\x13\x45xampleStreamStream\x12\x1f.example_service.ExampleRequest\x1a .example_service.ExampleResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'example_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EXAMPLEREQUEST']._serialized_start=42
  _globals['_EXAMPLEREQUEST']._serialized_end=107
  _globals['_EXAMPLERESPONSE']._serialized_start=109
  _globals['_EXAMPLERESPONSE']._serialized_end=175
  _globals['_TEST']._serialized_start=178
  _globals['_TEST']._serialized_end=548
# @@protoc_insertion_point(module_scope)
