# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: package_message.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("PackageMessage",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class PackageMessage(betterproto.Message):
    """ """

    c: "childpackage.ChildMessage" = betterproto.message_field(1)
    """
    
    """


from . import childpackage
