# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: field_name_identical_to_type.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)

import builtins

from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """
    Tests that messages may contain fields with names that are identical to their python types (PR #294)
    """

    int: builtins.int = betterproto_fw.int32_field(1)
    """
    
    """

    float: builtins.float = betterproto_fw.float_field(2)
    """
    
    """

    str: builtins.str = betterproto_fw.string_field(3)
    """
    
    """

    bytes: builtins.bytes = betterproto_fw.bytes_field(4)
    """
    
    """

    bool: builtins.bool = betterproto_fw.bool_field(5)
    """
    
    """
