# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: proto3_field_presence_oneof.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "InnerNested",
    "Nested",
    "WithOptional",
)


from dataclasses import dataclass
from typing import (
    Optional,
)

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    nested: "Nested" = betterproto.message_field(1, group="kind")
    """
    
    """

    with_optional: "WithOptional" = betterproto.message_field(2, group="kind")
    """
    
    """


@dataclass(eq=False, repr=False)
class InnerNested(betterproto.Message):
    """ """

    a: Optional[bool] = betterproto.bool_field(1, optional=True)
    """
    
    """


@dataclass(eq=False, repr=False)
class Nested(betterproto.Message):
    """ """

    inner: "InnerNested" = betterproto.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class WithOptional(betterproto.Message):
    """ """

    b: Optional[bool] = betterproto.bool_field(2, optional=True)
    """
    
    """
