# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: regression_414.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from typing import (
    List,
)

from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """ """

    body: bytes = betterproto_fw.bytes_field(1)
    """
    
    """

    auth: bytes = betterproto_fw.bytes_field(2)
    """
    
    """

    signatures: List[bytes] = betterproto_fw.bytes_field(3)
    """
    
    """
