# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: other.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("OtherPackageMessage",)


from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class OtherPackageMessage(betterproto_fw.Message):
    """ """

    root_package_message: "__import_circular_dependency__.RootPackageMessage" = (
        betterproto_fw.message_field(1)
    )
    """
    
    """


from ... import import_circular_dependency as __import_circular_dependency__
