# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google_impl_behavior_equivalence.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'google_impl_behavior_equivalence.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&google_impl_behavior_equivalence.proto\x12 google_impl_behavior_equivalence\x1a\x1fgoogle/protobuf/timestamp.proto\"\x12\n\x03\x46oo\x12\x0b\n\x03\x62\x61r\x18\x01 \x01(\x03\"j\n\x04Test\x12\x10\n\x06string\x18\x01 \x01(\tH\x00\x12\x11\n\x07integer\x18\x02 \x01(\x03H\x00\x12\x34\n\x03\x66oo\x18\x03 \x01(\x0b\x32%.google_impl_behavior_equivalence.FooH\x00\x42\x07\n\x05group\".\n\x04Spam\x12&\n\x02ts\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"?\n\x07Request\x12\x34\n\x03\x66oo\x18\x01 \x01(\x0b\x32\'.google_impl_behavior_equivalence.Empty\"\x07\n\x05\x45mptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google_impl_behavior_equivalence_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FOO']._serialized_start=109
  _globals['_FOO']._serialized_end=127
  _globals['_TEST']._serialized_start=129
  _globals['_TEST']._serialized_end=235
  _globals['_SPAM']._serialized_start=237
  _globals['_SPAM']._serialized_end=283
  _globals['_REQUEST']._serialized_start=285
  _globals['_REQUEST']._serialized_end=348
  _globals['_EMPTY']._serialized_start=350
  _globals['_EMPTY']._serialized_end=357
# @@protoc_insertion_point(module_scope)
