# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: import_service_input_message.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'import_service_input_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import request_message_pb2 as request__message__pb2
import child_package_request_message_pb2 as child__package__request__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"import_service_input_message.proto\x12\x1cimport_service_input_message\x1a\x15request_message.proto\x1a#child_package_request_message.proto\" \n\x0fRequestResponse\x12\r\n\x05value\x18\x01 \x01(\x05\"2\n\x06Nested\x1a(\n\x0eRequestMessage\x12\x16\n\x0enestedArgument\x18\x01 \x01(\x05\x32\xd2\x02\n\x04Test\x12\x66\n\x07\x44oThing\x12,.import_service_input_message.RequestMessage\x1a-.import_service_input_message.RequestResponse\x12r\n\x08\x44oThing2\x12\x37.import_service_input_message.child.ChildRequestMessage\x1a-.import_service_input_message.RequestResponse\x12n\n\x08\x44oThing3\x12\x33.import_service_input_message.Nested.RequestMessage\x1a-.import_service_input_message.RequestResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'import_service_input_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REQUESTRESPONSE']._serialized_start=128
  _globals['_REQUESTRESPONSE']._serialized_end=160
  _globals['_NESTED']._serialized_start=162
  _globals['_NESTED']._serialized_end=212
  _globals['_NESTED_REQUESTMESSAGE']._serialized_start=172
  _globals['_NESTED_REQUESTMESSAGE']._serialized_end=212
  _globals['_TEST']._serialized_start=215
  _globals['_TEST']._serialized_end=553
# @@protoc_insertion_point(module_scope)
