# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: oneof.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "MixedDrink",
    "Test",
)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class MixedDrink(betterproto.Message):
    """ """

    shots: int = betterproto.int32_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    pitied: int = betterproto.int32_field(1, group="foo")
    """
    
    """

    pitier: str = betterproto.string_field(2, group="foo")
    """
    
    """

    just_a_regular_field: int = betterproto.int32_field(3)
    """
    
    """

    drinks: int = betterproto.int32_field(11, group="bar")
    """
    
    """

    bar_name: str = betterproto.string_field(12, group="bar")
    """
    
    """

    mixed_drink: "MixedDrink" = betterproto.message_field(13, group="bar")
    """
    
    """
