# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nestedtwice.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'nestedtwice.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11nestedtwice.proto\x12\x0bnestedtwice\"\x96\x03\n\x04Test\x12\"\n\x03top\x18\x01 \x01(\x0b\x32\x15.nestedtwice.Test.Top\x1a\xe9\x02\n\x03Top\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x06middle\x18\x02 \x01(\x0b\x32\x1c.nestedtwice.Test.Top.Middle\x1a\xa5\x02\n\x06Middle\x12\x33\n\x06\x62ottom\x18\x02 \x03(\x0b\x32#.nestedtwice.Test.Top.Middle.Bottom\x12;\n\nenumBottom\x18\x03 \x03(\x0e\x32\'.nestedtwice.Test.Top.Middle.EnumBottom\x12\x45\n\x0ftopMiddleBottom\x18\x04 \x03(\x0b\x32,.nestedtwice.Test.Top.Middle.TopMiddleBottom\x12\x0b\n\x03\x62\x61r\x18\x05 \x01(\x08\x1a\x1c\n\x0fTopMiddleBottom\x12\t\n\x01\x61\x18\x01 \x01(\t\x1a\x15\n\x06\x42ottom\x12\x0b\n\x03\x66oo\x18\x01 \x01(\t\"\x1a\n\nEnumBottom\x12\x05\n\x01\x41\x10\x00\x12\x05\n\x01\x42\x10\x01J\x04\x08\x01\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nestedtwice_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=35
  _globals['_TEST']._serialized_end=441
  _globals['_TEST_TOP']._serialized_start=80
  _globals['_TEST_TOP']._serialized_end=441
  _globals['_TEST_TOP_MIDDLE']._serialized_start=148
  _globals['_TEST_TOP_MIDDLE']._serialized_end=441
  _globals['_TEST_TOP_MIDDLE_TOPMIDDLEBOTTOM']._serialized_start=356
  _globals['_TEST_TOP_MIDDLE_TOPMIDDLEBOTTOM']._serialized_end=384
  _globals['_TEST_TOP_MIDDLE_BOTTOM']._serialized_start=386
  _globals['_TEST_TOP_MIDDLE_BOTTOM']._serialized_end=407
  _globals['_TEST_TOP_MIDDLE_ENUMBOTTOM']._serialized_start=409
  _globals['_TEST_TOP_MIDDLE_ENUMBOTTOM']._serialized_end=435
# @@protoc_insertion_point(module_scope)
