# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rservice.proto\x12\x07service\"R\n\x0e\x44oThingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63omments\x18\x02 \x03(\t\x12 \n\x04type\x18\x03 \x01(\x0e\x32\x12.service.ThingType\" \n\x0f\x44oThingResponse\x12\r\n\x05names\x18\x01 \x03(\t\"\x1f\n\x0fGetThingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"1\n\x10GetThingResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05*.\n\tThingType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06LIVING\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x32\xa3\x02\n\x04Test\x12<\n\x07\x44oThing\x12\x17.service.DoThingRequest\x1a\x18.service.DoThingResponse\x12\x43\n\x0c\x44oManyThings\x12\x17.service.DoThingRequest\x1a\x18.service.DoThingResponse(\x01\x12I\n\x10GetThingVersions\x12\x18.service.GetThingRequest\x1a\x19.service.GetThingResponse0\x01\x12M\n\x12GetDifferentThings\x12\x18.service.GetThingRequest\x1a\x19.service.GetThingResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THINGTYPE']._serialized_start=228
  _globals['_THINGTYPE']._serialized_end=274
  _globals['_DOTHINGREQUEST']._serialized_start=26
  _globals['_DOTHINGREQUEST']._serialized_end=108
  _globals['_DOTHINGRESPONSE']._serialized_start=110
  _globals['_DOTHINGRESPONSE']._serialized_end=142
  _globals['_GETTHINGREQUEST']._serialized_start=144
  _globals['_GETTHINGREQUEST']._serialized_end=175
  _globals['_GETTHINGRESPONSE']._serialized_start=177
  _globals['_GETTHINGRESPONSE']._serialized_end=226
  _globals['_TEST']._serialized_start=277
  _globals['_TEST']._serialized_end=568
# @@protoc_insertion_point(module_scope)
