# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto3_field_presence_oneof.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'proto3_field_presence_oneof.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!proto3_field_presence_oneof.proto\x12\x1bproto3_field_presence_oneof\"\x89\x01\n\x04Test\x12\x35\n\x06nested\x18\x01 \x01(\x0b\x32#.proto3_field_presence_oneof.NestedH\x00\x12\x42\n\rwith_optional\x18\x02 \x01(\x0b\x32).proto3_field_presence_oneof.WithOptionalH\x00\x42\x06\n\x04kind\"#\n\x0bInnerNested\x12\x0e\n\x01\x61\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x04\n\x02_a\"A\n\x06Nested\x12\x37\n\x05inner\x18\x01 \x01(\x0b\x32(.proto3_field_presence_oneof.InnerNested\"$\n\x0cWithOptional\x12\x0e\n\x01\x62\x18\x02 \x01(\x08H\x00\x88\x01\x01\x42\x04\n\x02_bb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto3_field_presence_oneof_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=67
  _globals['_TEST']._serialized_end=204
  _globals['_INNERNESTED']._serialized_start=206
  _globals['_INNERNESTED']._serialized_end=241
  _globals['_NESTED']._serialized_start=243
  _globals['_NESTED']._serialized_end=308
  _globals['_WITHOPTIONAL']._serialized_start=310
  _globals['_WITHOPTIONAL']._serialized_end=346
# @@protoc_insertion_point(module_scope)
