# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: googletypes_response_embedded.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'googletypes_response_embedded.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#googletypes_response_embedded.proto\x12\x1dgoogletypes_response_embedded\x1a\x1egoogle/protobuf/wrappers.proto\"\x07\n\x05Input\"\xd0\x03\n\x06Output\x12\x32\n\x0c\x64ouble_value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0b\x66loat_value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0bint64_value\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0cuint64_value\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x30\n\x0bint32_value\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x32\n\x0cuint32_value\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12.\n\nbool_value\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0cstring_value\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\x0b\x62ytes_value\x18\t \x01(\x0b\x32\x1b.google.protobuf.BytesValue2`\n\x04Test\x12X\n\tgetOutput\x12$.googletypes_response_embedded.Input\x1a%.googletypes_response_embedded.Outputb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'googletypes_response_embedded_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INPUT']._serialized_start=102
  _globals['_INPUT']._serialized_end=109
  _globals['_OUTPUT']._serialized_start=112
  _globals['_OUTPUT']._serialized_end=576
  _globals['_TEST']._serialized_start=578
  _globals['_TEST']._serialized_end=674
# @@protoc_insertion_point(module_scope)
