# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: mapmessage.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "Nested",
)


from dataclasses import dataclass
from typing import (
    Dict,
)

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    items: Dict[str, "Nested"] = betterproto.map_field(
        1, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )
    """
    
    """


@dataclass(eq=False, repr=False)
class Nested(betterproto.Message):
    """ """

    count: int = betterproto.int32_field(1)
    """
    
    """
