# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: messages.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'messages.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0emessages.proto\x12)service_separate_packages.things.messages\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x87\x01\n\x0e\x44oThingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63omments\x18\x02 \x03(\t\x12(\n\x04when\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\" \n\x0f\x44oThingResponse\x12\r\n\x05names\x18\x01 \x03(\t\"\x1f\n\x0fGetThingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"1\n\x10GetThingResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'messages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DOTHINGREQUEST']._serialized_start=127
  _globals['_DOTHINGREQUEST']._serialized_end=262
  _globals['_DOTHINGRESPONSE']._serialized_start=264
  _globals['_DOTHINGRESPONSE']._serialized_end=296
  _globals['_GETTHINGREQUEST']._serialized_start=298
  _globals['_GETTHINGREQUEST']._serialized_end=329
  _globals['_GETTHINGRESPONSE']._serialized_start=331
  _globals['_GETTHINGRESPONSE']._serialized_end=380
# @@protoc_insertion_point(module_scope)
