# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: repeatedpacked.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass
from typing import (
    List,
)

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    counts: List[int] = betterproto_fw.int32_field(1)
    """
    
    """

    signed: List[int] = betterproto_fw.sint64_field(2)
    """
    
    """

    fixed: List[float] = betterproto_fw.double_field(3)
    """
    
    """
