# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: empty_repeated.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "MessageA",
    "Test",
)


from dataclasses import dataclass
from typing import (
    List,
)

import betterproto_fw


@dataclass(eq=False, repr=False)
class MessageA(betterproto_fw.Message):
    """ """

    values: List[float] = betterproto_fw.float_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    msg: List["MessageA"] = betterproto_fw.message_field(1)
    """
    
    """
