# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: namespace_keywords.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """
    Tests that messages may contain fields that are Python keywords

    Generated with Python 3.7.6
    print('\n'.join(f'string {k} = {i+1};' for i,k in enumerate(keyword.kwlist)))
    """

    false: str = betterproto_fw.string_field(1)
    """
    
    """

    none: str = betterproto_fw.string_field(2)
    """
    
    """

    true: str = betterproto_fw.string_field(3)
    """
    
    """

    and_: str = betterproto_fw.string_field(4)
    """
    
    """

    as_: str = betterproto_fw.string_field(5)
    """
    
    """

    assert_: str = betterproto_fw.string_field(6)
    """
    
    """

    async_: str = betterproto_fw.string_field(7)
    """
    
    """

    await_: str = betterproto_fw.string_field(8)
    """
    
    """

    break_: str = betterproto_fw.string_field(9)
    """
    
    """

    class_: str = betterproto_fw.string_field(10)
    """
    
    """

    continue_: str = betterproto_fw.string_field(11)
    """
    
    """

    def_: str = betterproto_fw.string_field(12)
    """
    
    """

    del_: str = betterproto_fw.string_field(13)
    """
    
    """

    elif_: str = betterproto_fw.string_field(14)
    """
    
    """

    else_: str = betterproto_fw.string_field(15)
    """
    
    """

    except_: str = betterproto_fw.string_field(16)
    """
    
    """

    finally_: str = betterproto_fw.string_field(17)
    """
    
    """

    for_: str = betterproto_fw.string_field(18)
    """
    
    """

    from_: str = betterproto_fw.string_field(19)
    """
    
    """

    global_: str = betterproto_fw.string_field(20)
    """
    
    """

    if_: str = betterproto_fw.string_field(21)
    """
    
    """

    import_: str = betterproto_fw.string_field(22)
    """
    
    """

    in_: str = betterproto_fw.string_field(23)
    """
    
    """

    is_: str = betterproto_fw.string_field(24)
    """
    
    """

    lambda_: str = betterproto_fw.string_field(25)
    """
    
    """

    nonlocal_: str = betterproto_fw.string_field(26)
    """
    
    """

    not_: str = betterproto_fw.string_field(27)
    """
    
    """

    or_: str = betterproto_fw.string_field(28)
    """
    
    """

    pass_: str = betterproto_fw.string_field(29)
    """
    
    """

    raise_: str = betterproto_fw.string_field(30)
    """
    
    """

    return_: str = betterproto_fw.string_field(31)
    """
    
    """

    try_: str = betterproto_fw.string_field(32)
    """
    
    """

    while_: str = betterproto_fw.string_field(33)
    """
    
    """

    with_: str = betterproto_fw.string_field(34)
    """
    
    """

    yield_: str = betterproto_fw.string_field(35)
    """
    
    """
