# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: fixed.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    foo: int = betterproto.fixed32_field(1)
    """
    
    """

    bar: int = betterproto.sfixed32_field(2)
    """
    
    """

    baz: int = betterproto.fixed64_field(3)
    """
    
    """

    qux: int = betterproto.sfixed64_field(4)
    """
    
    """
