# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: oneof_default_value_serialization.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Message",
    "NestedMessage",
    "Test",
)


from dataclasses import dataclass
from datetime import datetime, timedelta
from typing import (
    Optional,
)

import betterproto_fw


@dataclass(eq=False, repr=False)
class Message(betterproto_fw.Message):
    """ """

    value: int = betterproto_fw.int64_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class NestedMessage(betterproto_fw.Message):
    """ """

    id: int = betterproto_fw.int64_field(1)
    """
    
    """

    wrapped_message_value: "Message" = betterproto_fw.message_field(
        2, group="value_type"
    )
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    bool_value: bool = betterproto_fw.bool_field(1, group="value_type")
    """
    
    """

    int64_value: int = betterproto_fw.int64_field(2, group="value_type")
    """
    
    """

    timestamp_value: datetime = betterproto_fw.message_field(3, group="value_type")
    """
    
    """

    duration_value: timedelta = betterproto_fw.message_field(4, group="value_type")
    """
    
    """

    wrapped_message_value: "Message" = betterproto_fw.message_field(
        5, group="value_type"
    )
    """
    
    """

    wrapped_nested_message_value: "NestedMessage" = betterproto_fw.message_field(
        6, group="value_type"
    )
    """
    
    """

    wrapped_bool_value: Optional[bool] = betterproto_fw.message_field(
        7, wraps=betterproto_fw.TYPE_BOOL, group="value_type"
    )
    """
    
    """
