# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: googletypes_struct.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    struct: "betterproto_fw_lib_google_protobuf.Struct" = betterproto_fw.message_field(
        1
    )
    """
    
    """


import betterproto_fw.lib.google.protobuf as betterproto_fw_lib_google_protobuf
