# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: namespace_builtin_types.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)

import builtins
from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """
    Tests that messages may contain fields with names that are python types
    """

    int: str = betterproto.string_field(1)
    """
    https://docs.python.org/2/library/stdtypes.html#numeric-types-int-float-long-complex
    """

    float: str = betterproto.string_field(2)
    """
    
    """

    complex: str = betterproto.string_field(3)
    """
    
    """

    list: str = betterproto.string_field(4)
    """
    https://docs.python.org/3/library/stdtypes.html#sequence-types-list-tuple-range
    """

    tuple: str = betterproto.string_field(5)
    """
    
    """

    range: str = betterproto.string_field(6)
    """
    
    """

    str: builtins.str = betterproto.string_field(7)
    """https://docs.python.org/3/library/stdtypes.html#str"""

    bytearray: builtins.str = betterproto.string_field(8)
    """https://docs.python.org/3/library/stdtypes.html#bytearray-objects"""

    bytes: builtins.str = betterproto.string_field(9)
    """
    https://docs.python.org/3/library/stdtypes.html#bytes-and-bytearray-operations
    """

    memoryview: builtins.str = betterproto.string_field(10)
    """https://docs.python.org/3/library/stdtypes.html#memory-views"""

    set: builtins.str = betterproto.string_field(11)
    """
    https://docs.python.org/3/library/stdtypes.html#set-types-set-frozenset
    """

    frozenset: builtins.str = betterproto.string_field(12)
    """
    
    """

    map: builtins.str = betterproto.string_field(13)
    """https://docs.python.org/3/library/stdtypes.html#dict"""

    dict: builtins.str = betterproto.string_field(14)
    """
    
    """

    bool: builtins.str = betterproto.string_field(15)
    """https://docs.python.org/3/library/stdtypes.html#boolean-values"""
