# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: googletypes.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from datetime import datetime, timedelta
from typing import (
    Optional,
)

from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    maybe: Optional[bool] = betterproto.message_field(1, wraps=betterproto.TYPE_BOOL)
    """
    
    """

    ts: datetime = betterproto.message_field(2)
    """
    
    """

    duration: timedelta = betterproto.message_field(3)
    """
    
    """

    important: Optional[int] = betterproto.message_field(
        4, wraps=betterproto.TYPE_INT32
    )
    """
    
    """

    empty: "betterproto_lib_pydantic_google_protobuf.Empty" = betterproto.message_field(
        5
    )
    """
    
    """


import betterproto.lib.pydantic.google.protobuf as betterproto_lib_pydantic_google_protobuf
