# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: root.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("RootMessage",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class RootMessage(betterproto.Message):
    """ """

    pass
