# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: child_package_request_message.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("ChildRequestMessage",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class ChildRequestMessage(betterproto.Message):
    """ """

    child_argument: int = betterproto.int32_field(1)
    """
    
    """
