# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nested.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'nested.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cnested.proto\x12\x06nested\"\xc3\x01\n\x04Test\x12#\n\x06nested\x18\x01 \x01(\x0b\x32\x13.nested.Test.Nested\x12 \n\x07sibling\x18\x02 \x01(\x0b\x32\x0f.nested.Sibling\x12!\n\x08sibling2\x18\x03 \x01(\x0b\x32\x0f.nested.Sibling\x12\x1d\n\x03msg\x18\x04 \x01(\x0e\x32\x10.nested.Test.Msg\x1a\x17\n\x06Nested\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"\x19\n\x03Msg\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04THIS\x10\x01\"\x16\n\x07Sibling\x12\x0b\n\x03\x66oo\x18\x01 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nested_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=25
  _globals['_TEST']._serialized_end=220
  _globals['_TEST_NESTED']._serialized_start=170
  _globals['_TEST_NESTED']._serialized_end=193
  _globals['_TEST_MSG']._serialized_start=195
  _globals['_TEST_MSG']._serialized_end=220
  _globals['_SIBLING']._serialized_start=222
  _globals['_SIBLING']._serialized_end=244
# @@protoc_insertion_point(module_scope)
