# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: example.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'example.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rexample.proto\x12\x07\x65xample\"?\n\x11\x46ileDescriptorSet\x12*\n\x04\x66ile\x18\x01 \x03(\x0b\x32\x1c.example.FileDescriptorProto\"\xab\x03\n\x13\x46ileDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07package\x18\x02 \x01(\t\x12\x12\n\ndependency\x18\x03 \x03(\t\x12\x19\n\x11public_dependency\x18\n \x03(\x05\x12\x17\n\x0fweak_dependency\x18\x0b \x03(\x05\x12.\n\x0cmessage_type\x18\x04 \x03(\x0b\x32\x18.example.DescriptorProto\x12/\n\tenum_type\x18\x05 \x03(\x0b\x32\x1c.example.EnumDescriptorProto\x12\x30\n\x07service\x18\x06 \x03(\x0b\x32\x1f.example.ServiceDescriptorProto\x12\x30\n\textension\x18\x07 \x03(\x0b\x32\x1d.example.FieldDescriptorProto\x12%\n\x07options\x18\x08 \x01(\x0b\x32\x14.example.FileOptions\x12\x31\n\x10source_code_info\x18\t \x01(\x0b\x32\x17.example.SourceCodeInfo\x12\x0e\n\x06syntax\x18\x0c \x01(\t\"\xe1\x04\n\x0f\x44\x65scriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x05\x66ield\x18\x02 \x03(\x0b\x32\x1d.example.FieldDescriptorProto\x12\x30\n\textension\x18\x06 \x03(\x0b\x32\x1d.example.FieldDescriptorProto\x12-\n\x0bnested_type\x18\x03 \x03(\x0b\x32\x18.example.DescriptorProto\x12/\n\tenum_type\x18\x04 \x03(\x0b\x32\x1c.example.EnumDescriptorProto\x12@\n\x0f\x65xtension_range\x18\x05 \x03(\x0b\x32\'.example.DescriptorProto.ExtensionRange\x12\x31\n\noneof_decl\x18\x08 \x03(\x0b\x32\x1d.example.OneofDescriptorProto\x12(\n\x07options\x18\x07 \x01(\x0b\x32\x17.example.MessageOptions\x12>\n\x0ereserved_range\x18\t \x03(\x0b\x32&.example.DescriptorProto.ReservedRange\x12\x15\n\rreserved_name\x18\n \x03(\t\x1a]\n\x0e\x45xtensionRange\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x05\x12/\n\x07options\x18\x03 \x01(\x0b\x32\x1e.example.ExtensionRangeOptions\x1a+\n\rReservedRange\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x05\"_\n\x15\x45xtensionRangeOptions\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02\"\xbd\x05\n\x14\x46ieldDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x03 \x01(\x05\x12\x32\n\x05label\x18\x04 \x01(\x0e\x32#.example.FieldDescriptorProto.Label\x12\x30\n\x04type\x18\x05 \x01(\x0e\x32\".example.FieldDescriptorProto.Type\x12\x11\n\ttype_name\x18\x06 \x01(\t\x12\x10\n\x08\x65xtendee\x18\x02 \x01(\t\x12\x15\n\rdefault_value\x18\x07 \x01(\t\x12\x13\n\x0boneof_index\x18\t \x01(\x05\x12\x11\n\tjson_name\x18\n \x01(\t\x12&\n\x07options\x18\x08 \x01(\x0b\x32\x15.example.FieldOptions\x12\x17\n\x0fproto3_optional\x18\x11 \x01(\x08\"\xb6\x02\n\x04Type\x12\x0f\n\x0bTYPE_DOUBLE\x10\x01\x12\x0e\n\nTYPE_FLOAT\x10\x02\x12\x0e\n\nTYPE_INT64\x10\x03\x12\x0f\n\x0bTYPE_UINT64\x10\x04\x12\x0e\n\nTYPE_INT32\x10\x05\x12\x10\n\x0cTYPE_FIXED64\x10\x06\x12\x10\n\x0cTYPE_FIXED32\x10\x07\x12\r\n\tTYPE_BOOL\x10\x08\x12\x0f\n\x0bTYPE_STRING\x10\t\x12\x0e\n\nTYPE_GROUP\x10\n\x12\x10\n\x0cTYPE_MESSAGE\x10\x0b\x12\x0e\n\nTYPE_BYTES\x10\x0c\x12\x0f\n\x0bTYPE_UINT32\x10\r\x12\r\n\tTYPE_ENUM\x10\x0e\x12\x11\n\rTYPE_SFIXED32\x10\x0f\x12\x11\n\rTYPE_SFIXED64\x10\x10\x12\x0f\n\x0bTYPE_SINT32\x10\x11\x12\x0f\n\x0bTYPE_SINT64\x10\x12\"C\n\x05Label\x12\x12\n\x0eLABEL_OPTIONAL\x10\x01\x12\x12\n\x0eLABEL_REQUIRED\x10\x02\x12\x12\n\x0eLABEL_REPEATED\x10\x03\"L\n\x14OneofDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x07options\x18\x02 \x01(\x0b\x32\x15.example.OneofOptions\"\x8c\x02\n\x13\x45numDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x03(\x0b\x32!.example.EnumValueDescriptorProto\x12%\n\x07options\x18\x03 \x01(\x0b\x32\x14.example.EnumOptions\x12\x46\n\x0ereserved_range\x18\x04 \x03(\x0b\x32..example.EnumDescriptorProto.EnumReservedRange\x12\x15\n\rreserved_name\x18\x05 \x03(\t\x1a/\n\x11\x45numReservedRange\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x05\"d\n\x18\x45numValueDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12*\n\x07options\x18\x03 \x01(\x0b\x32\x19.example.EnumValueOptions\"\x80\x01\n\x16ServiceDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x06method\x18\x02 \x03(\x0b\x32\x1e.example.MethodDescriptorProto\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.example.ServiceOptions\"\xb9\x01\n\x15MethodDescriptorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ninput_type\x18\x02 \x01(\t\x12\x13\n\x0boutput_type\x18\x03 \x01(\t\x12\'\n\x07options\x18\x04 \x01(\x0b\x32\x16.example.MethodOptions\x12\x1f\n\x10\x63lient_streaming\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x10server_streaming\x18\x06 \x01(\x08:\x05\x66\x61lse\"\x95\x06\n\x0b\x46ileOptions\x12\x14\n\x0cjava_package\x18\x01 \x01(\t\x12\x1c\n\x14java_outer_classname\x18\x08 \x01(\t\x12\"\n\x13java_multiple_files\x18\n \x01(\x08:\x05\x66\x61lse\x12)\n\x1djava_generate_equals_and_hash\x18\x14 \x01(\x08\x42\x02\x18\x01\x12%\n\x16java_string_check_utf8\x18\x1b \x01(\x08:\x05\x66\x61lse\x12>\n\x0coptimize_for\x18\t \x01(\x0e\x32!.example.FileOptions.OptimizeMode:\x05SPEED\x12\x12\n\ngo_package\x18\x0b \x01(\t\x12\"\n\x13\x63\x63_generic_services\x18\x10 \x01(\x08:\x05\x66\x61lse\x12$\n\x15java_generic_services\x18\x11 \x01(\x08:\x05\x66\x61lse\x12\"\n\x13py_generic_services\x18\x12 \x01(\x08:\x05\x66\x61lse\x12#\n\x14php_generic_services\x18* \x01(\x08:\x05\x66\x61lse\x12\x19\n\ndeprecated\x18\x17 \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x10\x63\x63_enable_arenas\x18\x1f \x01(\x08:\x04true\x12\x19\n\x11objc_class_prefix\x18$ \x01(\t\x12\x18\n\x10\x63sharp_namespace\x18% \x01(\t\x12\x14\n\x0cswift_prefix\x18\' \x01(\t\x12\x18\n\x10php_class_prefix\x18( \x01(\t\x12\x15\n\rphp_namespace\x18) \x01(\t\x12\x1e\n\x16php_metadata_namespace\x18, \x01(\t\x12\x14\n\x0cruby_package\x18- \x01(\t\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption\":\n\x0cOptimizeMode\x12\t\n\x05SPEED\x10\x01\x12\r\n\tCODE_SIZE\x10\x02\x12\x10\n\x0cLITE_RUNTIME\x10\x03*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08&\x10\'\"\xea\x01\n\x0eMessageOptions\x12&\n\x17message_set_wire_format\x18\x01 \x01(\x08:\x05\x66\x61lse\x12.\n\x1fno_standard_descriptor_accessor\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x19\n\ndeprecated\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x11\n\tmap_entry\x18\x07 \x01(\x08\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08\x08\x10\tJ\x04\x08\t\x10\n\"\x86\x03\n\x0c\x46ieldOptions\x12\x32\n\x05\x63type\x18\x01 \x01(\x0e\x32\x1b.example.FieldOptions.CType:\x06STRING\x12\x0e\n\x06packed\x18\x02 \x01(\x08\x12\x37\n\x06jstype\x18\x06 \x01(\x0e\x32\x1c.example.FieldOptions.JSType:\tJS_NORMAL\x12\x13\n\x04lazy\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x19\n\ndeprecated\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x13\n\x04weak\x18\n \x01(\x08:\x05\x66\x61lse\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption\"/\n\x05\x43Type\x12\n\n\x06STRING\x10\x00\x12\x08\n\x04\x43ORD\x10\x01\x12\x10\n\x0cSTRING_PIECE\x10\x02\"5\n\x06JSType\x12\r\n\tJS_NORMAL\x10\x00\x12\r\n\tJS_STRING\x10\x01\x12\r\n\tJS_NUMBER\x10\x02*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08\x04\x10\x05\"V\n\x0cOneofOptions\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02\"\x8b\x01\n\x0b\x45numOptions\x12\x13\n\x0b\x61llow_alias\x18\x02 \x01(\x08\x12\x19\n\ndeprecated\x18\x03 \x01(\x08:\x05\x66\x61lse\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08\x05\x10\x06\"u\n\x10\x45numValueOptions\x12\x19\n\ndeprecated\x18\x01 \x01(\x08:\x05\x66\x61lse\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02\"s\n\x0eServiceOptions\x12\x19\n\ndeprecated\x18! \x01(\x08:\x05\x66\x61lse\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02\"\x9d\x02\n\rMethodOptions\x12\x19\n\ndeprecated\x18! \x01(\x08:\x05\x66\x61lse\x12W\n\x11idempotency_level\x18\" \x01(\x0e\x32\'.example.MethodOptions.IdempotencyLevel:\x13IDEMPOTENCY_UNKNOWN\x12;\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32\x1c.example.UninterpretedOption\"P\n\x10IdempotencyLevel\x12\x17\n\x13IDEMPOTENCY_UNKNOWN\x10\x00\x12\x13\n\x0fNO_SIDE_EFFECTS\x10\x01\x12\x0e\n\nIDEMPOTENT\x10\x02*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02\"\x96\x02\n\x13UninterpretedOption\x12\x33\n\x04name\x18\x02 \x03(\x0b\x32%.example.UninterpretedOption.NamePart\x12\x18\n\x10identifier_value\x18\x03 \x01(\t\x12\x1a\n\x12positive_int_value\x18\x04 \x01(\x04\x12\x1a\n\x12negative_int_value\x18\x05 \x01(\x03\x12\x14\n\x0c\x64ouble_value\x18\x06 \x01(\x01\x12\x14\n\x0cstring_value\x18\x07 \x01(\x0c\x12\x17\n\x0f\x61ggregate_value\x18\x08 \x01(\t\x1a\x33\n\x08NamePart\x12\x11\n\tname_part\x18\x01 \x02(\t\x12\x14\n\x0cis_extension\x18\x02 \x02(\x08\"\xcd\x01\n\x0eSourceCodeInfo\x12\x32\n\x08location\x18\x01 \x03(\x0b\x32 .example.SourceCodeInfo.Location\x1a\x86\x01\n\x08Location\x12\x10\n\x04path\x18\x01 \x03(\x05\x42\x02\x10\x01\x12\x10\n\x04span\x18\x02 \x03(\x05\x42\x02\x10\x01\x12\x18\n\x10leading_comments\x18\x03 \x01(\t\x12\x19\n\x11trailing_comments\x18\x04 \x01(\t\x12!\n\x19leading_detached_comments\x18\x06 \x03(\t\"\x9f\x01\n\x11GeneratedCodeInfo\x12\x39\n\nannotation\x18\x01 \x03(\x0b\x32%.example.GeneratedCodeInfo.Annotation\x1aO\n\nAnnotation\x12\x10\n\x04path\x18\x01 \x03(\x05\x42\x02\x10\x01\x12\x13\n\x0bsource_file\x18\x02 \x01(\t\x12\r\n\x05\x62\x65gin\x18\x03 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x05\x42~\n\x13\x63om.google.protobufB\x10\x44\x65scriptorProtosH\x01Z-google.golang.org/protobuf/types/descriptorpb\xf8\x01\x01\xa2\x02\x03GPB\xaa\x02\x1aGoogle.Protobuf.Reflection')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'example_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.google.protobufB\020DescriptorProtosH\001Z-google.golang.org/protobuf/types/descriptorpb\370\001\001\242\002\003GPB\252\002\032Google.Protobuf.Reflection'
  _globals['_FILEOPTIONS'].fields_by_name['java_generate_equals_and_hash']._loaded_options = None
  _globals['_FILEOPTIONS'].fields_by_name['java_generate_equals_and_hash']._serialized_options = b'\030\001'
  _globals['_SOURCECODEINFO_LOCATION'].fields_by_name['path']._loaded_options = None
  _globals['_SOURCECODEINFO_LOCATION'].fields_by_name['path']._serialized_options = b'\020\001'
  _globals['_SOURCECODEINFO_LOCATION'].fields_by_name['span']._loaded_options = None
  _globals['_SOURCECODEINFO_LOCATION'].fields_by_name['span']._serialized_options = b'\020\001'
  _globals['_GENERATEDCODEINFO_ANNOTATION'].fields_by_name['path']._loaded_options = None
  _globals['_GENERATEDCODEINFO_ANNOTATION'].fields_by_name['path']._serialized_options = b'\020\001'
  _globals['_FILEDESCRIPTORSET']._serialized_start=26
  _globals['_FILEDESCRIPTORSET']._serialized_end=89
  _globals['_FILEDESCRIPTORPROTO']._serialized_start=92
  _globals['_FILEDESCRIPTORPROTO']._serialized_end=519
  _globals['_DESCRIPTORPROTO']._serialized_start=522
  _globals['_DESCRIPTORPROTO']._serialized_end=1131
  _globals['_DESCRIPTORPROTO_EXTENSIONRANGE']._serialized_start=993
  _globals['_DESCRIPTORPROTO_EXTENSIONRANGE']._serialized_end=1086
  _globals['_DESCRIPTORPROTO_RESERVEDRANGE']._serialized_start=1088
  _globals['_DESCRIPTORPROTO_RESERVEDRANGE']._serialized_end=1131
  _globals['_EXTENSIONRANGEOPTIONS']._serialized_start=1133
  _globals['_EXTENSIONRANGEOPTIONS']._serialized_end=1228
  _globals['_FIELDDESCRIPTORPROTO']._serialized_start=1231
  _globals['_FIELDDESCRIPTORPROTO']._serialized_end=1932
  _globals['_FIELDDESCRIPTORPROTO_TYPE']._serialized_start=1553
  _globals['_FIELDDESCRIPTORPROTO_TYPE']._serialized_end=1863
  _globals['_FIELDDESCRIPTORPROTO_LABEL']._serialized_start=1865
  _globals['_FIELDDESCRIPTORPROTO_LABEL']._serialized_end=1932
  _globals['_ONEOFDESCRIPTORPROTO']._serialized_start=1934
  _globals['_ONEOFDESCRIPTORPROTO']._serialized_end=2010
  _globals['_ENUMDESCRIPTORPROTO']._serialized_start=2013
  _globals['_ENUMDESCRIPTORPROTO']._serialized_end=2281
  _globals['_ENUMDESCRIPTORPROTO_ENUMRESERVEDRANGE']._serialized_start=2234
  _globals['_ENUMDESCRIPTORPROTO_ENUMRESERVEDRANGE']._serialized_end=2281
  _globals['_ENUMVALUEDESCRIPTORPROTO']._serialized_start=2283
  _globals['_ENUMVALUEDESCRIPTORPROTO']._serialized_end=2383
  _globals['_SERVICEDESCRIPTORPROTO']._serialized_start=2386
  _globals['_SERVICEDESCRIPTORPROTO']._serialized_end=2514
  _globals['_METHODDESCRIPTORPROTO']._serialized_start=2517
  _globals['_METHODDESCRIPTORPROTO']._serialized_end=2702
  _globals['_FILEOPTIONS']._serialized_start=2705
  _globals['_FILEOPTIONS']._serialized_end=3494
  _globals['_FILEOPTIONS_OPTIMIZEMODE']._serialized_start=3419
  _globals['_FILEOPTIONS_OPTIMIZEMODE']._serialized_end=3477
  _globals['_MESSAGEOPTIONS']._serialized_start=3497
  _globals['_MESSAGEOPTIONS']._serialized_end=3731
  _globals['_FIELDOPTIONS']._serialized_start=3734
  _globals['_FIELDOPTIONS']._serialized_end=4124
  _globals['_FIELDOPTIONS_CTYPE']._serialized_start=4005
  _globals['_FIELDOPTIONS_CTYPE']._serialized_end=4052
  _globals['_FIELDOPTIONS_JSTYPE']._serialized_start=4054
  _globals['_FIELDOPTIONS_JSTYPE']._serialized_end=4107
  _globals['_ONEOFOPTIONS']._serialized_start=4126
  _globals['_ONEOFOPTIONS']._serialized_end=4212
  _globals['_ENUMOPTIONS']._serialized_start=4215
  _globals['_ENUMOPTIONS']._serialized_end=4354
  _globals['_ENUMVALUEOPTIONS']._serialized_start=4356
  _globals['_ENUMVALUEOPTIONS']._serialized_end=4473
  _globals['_SERVICEOPTIONS']._serialized_start=4475
  _globals['_SERVICEOPTIONS']._serialized_end=4590
  _globals['_METHODOPTIONS']._serialized_start=4593
  _globals['_METHODOPTIONS']._serialized_end=4878
  _globals['_METHODOPTIONS_IDEMPOTENCYLEVEL']._serialized_start=4787
  _globals['_METHODOPTIONS_IDEMPOTENCYLEVEL']._serialized_end=4867
  _globals['_UNINTERPRETEDOPTION']._serialized_start=4881
  _globals['_UNINTERPRETEDOPTION']._serialized_end=5159
  _globals['_UNINTERPRETEDOPTION_NAMEPART']._serialized_start=5108
  _globals['_UNINTERPRETEDOPTION_NAMEPART']._serialized_end=5159
  _globals['_SOURCECODEINFO']._serialized_start=5162
  _globals['_SOURCECODEINFO']._serialized_end=5367
  _globals['_SOURCECODEINFO_LOCATION']._serialized_start=5233
  _globals['_SOURCECODEINFO_LOCATION']._serialized_end=5367
  _globals['_GENERATEDCODEINFO']._serialized_start=5370
  _globals['_GENERATEDCODEINFO']._serialized_end=5529
  _globals['_GENERATEDCODEINFO_ANNOTATION']._serialized_start=5450
  _globals['_GENERATEDCODEINFO_ANNOTATION']._serialized_end=5529
# @@protoc_insertion_point(module_scope)
