# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: ref.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    greeting: "_repeatedmessage__.Sub" = betterproto.message_field(1)
    """
    
    """


from .. import repeatedmessage as _repeatedmessage__
