# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: recursivemessage.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "Intermediate",
)


from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """ """

    name: str = betterproto_fw.string_field(1)
    """
    
    """

    child: "Test" = betterproto_fw.message_field(2)
    """
    
    """

    intermediate: "Intermediate" = betterproto_fw.message_field(3)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Intermediate(betterproto_fw.Message):
    """ """

    number: int = betterproto_fw.int32_field(1)
    """
    
    """

    child: "Test" = betterproto_fw.message_field(2)
    """
    
    """
