# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: test.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """Verify that we can import message unrelated to us"""

    message: "__cousin_cousin_subpackage__.CousinMessage" = betterproto.message_field(1)
    """
    
    """


from ...cousin import cousin_subpackage as __cousin_cousin_subpackage__
